@@ -10,20 +10,23 @@ def fastapi():
     pass
 
 
-@click.command()
+@fastapi.command()
 def main():
     app = MainApp()
     app.create_app()
 
 
-@click.command()
+@fastapi.command()
+@click.option('--is_only_orm', is_flag=False)
 @click.option('--db_host', default="localhost")
 @click.option('--db_name', default='test')
 @click.option('--db_user', default="test")
 @click.option('--db_pswd', default="test")
-def orm(db_name, db_host, db_user, db_pswd):
+def orm(db_name, db_host, db_user, db_pswd, is_only_orm):
     app = MainApp()
-    app.create_app_with_orm(db_name=db_name, db_pswd=db_pswd, db_host=db_host, db_user=db_user)
+    app.create_app_with_orm(
+        db_name=db_name, db_pswd=db_pswd, db_host=db_host, db_user=db_user, is_only_orm=is_only_orm
+    )
 
 
 @fastapi.command()
