@@ -14,8 +14,11 @@ class MainApp:
         self.write_files()
 
     def create_app_with_orm(
-            self, db_name: str, db_host: str, db_user: str, db_pswd: str):
-        self.write_files()
+            self, db_name: str = '', db_host: str = '', db_user: str = '', db_pswd: str = '',
+            is_only_orm: bool = False
+    ):
+        if not is_only_orm:
+            self.write_files()
         self.generate_orm(db_name=db_name, db_host=db_host, db_user=db_user, db_pswd=db_pswd)
 
     def write_files(self):
